@@ -1,5 +1,5 @@
 from decimal import Decimal
-from typing import Optional, Dict
+from typing import Optional, Dict, List
 from hashlib import md5
 
 from pydantic import BaseModel
@@ -43,7 +43,7 @@ class Experience(BaseModel):
     end_datetime: Optional[str] = None
     is_primary: Optional[bool] = None
     job_title: Optional[str] = None
-    job_title_levels: Optional[list[str]] = None
+    job_title_levels: Optional[List[str]] = None
 
     @staticmethod
     def from_pdl(pdl_input: Dict[str, any]) -> Optional['Experience']:
@@ -62,8 +62,8 @@ class Experience(BaseModel):
 
 
 class Degree(BaseModel):
-    levels: Optional[list[str]] = None
-    majors: Optional[list[str]] = None
+    levels: Optional[List[str]] = None
+    majors: Optional[List[str]] = None
 
 
 class Education(BaseModel):
@@ -105,15 +105,15 @@ class Person(IngestedDataType):
     headline: Optional[str] = None
     about: Optional[str] = None
     email: Optional[str] = None
-    personal_emails: Optional[list[str]] = None
-    phone_numbers: Optional[list[str]] = None
+    personal_emails: Optional[List[str]] = None
+    phone_numbers: Optional[List[str]] = None
     linkedin_url: Optional[str] = None
     linkedin_internal_id: Optional[str] = None
     industry: Optional[str] = None
     company_id: Optional[str] = None
     job_title: Optional[str] = None
-    canonical_job_titles: Optional[list[CanonicalJobTitle]] = None
-    job_title_levels: Optional[list[str]] = None
+    canonical_job_titles: Optional[List[CanonicalJobTitle]] = None
+    job_title_levels: Optional[List[str]] = None
     job_role_description: Optional[str] = None
     job_start_date: Optional[str] = None
     company_name: Optional[str] = None
@@ -121,13 +121,13 @@ class Person(IngestedDataType):
     company_industry: Optional[str] = None
     company_year_founded: Optional[int] = None
     job_last_updated: Optional[str] = None
-    interests: Optional[list[str]] = None
-    skills: Optional[list[str]] = None
-    experience: Optional[list[Experience]] = None
-    education: Optional[list[Education]] = None
-    languages: Optional[list[Language]] = None
+    interests: Optional[List[str]] = None
+    skills: Optional[List[str]] = None
+    experience: Optional[List[Experience]] = None
+    education: Optional[List[Education]] = None
+    languages: Optional[List[Language]] = None
     location: Optional[Location] = None
-    tags: Optional[list[str]] = None
+    tags: Optional[List[str]] = None
     uploaded_by_user_id: Optional[str] = None
     last_enriched_at: Optional[str] = None
     telescope_icp: Optional[bool] = None
