@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Optional
+from typing import Optional, List
 
 from pydantic import BaseModel
 
@@ -29,7 +29,7 @@ class Prospect(UserFacingDataType):
     first_name: str
     last_name: str
     company_name: str
-    sequence_step_history: list[ProspectSequenceStepEvent]
+    sequence_step_history: List[ProspectSequenceStepEvent]
     job_title: Optional[str] = None
     email: Optional[str] = None
     average_sentiment: Optional[float] = None
